@@ -3,13 +3,17 @@ package config
 import (
 	"bytes"
 	"fmt"
+	"os"
 	stdOS "os"
 	"path/filepath"
+	"runtime"
 	"strings"
 	"time"
 
 	"github.com/gookit/goutil/jsonutil"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 
 	json "github.com/goccy/go-json"
@@ -18,11 +22,13 @@ import (
 )
 
 // LoadConfig returns the default configuration including possible user overrides
-func Load(env runtime.Environment) *Config {
-	cfg := loadConfig(env)
+func Load(configFile, sh string, migrate bool) *Config {
+	defer log.Trace(time.Now())
+
+	cfg := loadConfig(configFile)
 
 	// only migrate automatically when the switch isn't set
-	if !env.Flags().Migrate && cfg.Version < Version {
+	if !migrate && cfg.Version < Version {
 		cfg.BackupAndMigrate()
 	}
 
@@ -39,7 +45,7 @@ func Load(env runtime.Environment) *Config {
 	// elv   - broken OSC sequences
 	// xonsh - broken OSC sequences
 	// tcsh  - overall broken, FTCS_COMMAND_EXECUTED could be added to POSH_POSTCMD in the future
-	switch env.Shell() {
+	switch sh {
 	case shell.ELVISH, shell.XONSH, shell.TCSH, shell.NU:
 		cfg.ShellIntegration = false
 	}
@@ -47,24 +53,71 @@ func Load(env runtime.Environment) *Config {
 	return cfg
 }
 
-func loadConfig(env runtime.Environment) *Config {
-	defer env.Trace(time.Now())
-	configFile := env.Flags().Config
+func Path(config string) string {
+	defer log.Trace(time.Now())
+
+	// if the config flag is set, we'll use that over POSH_THEME
+	// in our internal shell logic, we'll always use the POSH_THEME
+	// due to not using --config to set the configuration
+	hasConfig := len(config) > 0
+
+	if poshTheme := os.Getenv("POSH_THEME"); len(poshTheme) > 0 && !hasConfig {
+		log.Debug("config set using POSH_THEME:", poshTheme)
+		return poshTheme
+	}
+
+	if len(config) == 0 {
+		return ""
+	}
+
+	if strings.HasPrefix(config, "https://") {
+		filePath, err := Download(cache.Path(), config)
+		if err != nil {
+			log.Error(err)
+			return ""
+		}
+
+		return filePath
+	}
+
+	isCygwin := func() bool {
+		return runtime.GOOS == "windows" && len(os.Getenv("OSTYPE")) > 0
+	}
+
+	// Cygwin path always needs the full path as we're on Windows but not really.
+	// Doing filepath actions will convert it to a Windows path and break the init script.
+	if isCygwin() {
+		log.Debug("cygwin detected, using full path for config")
+		return config
+	}
+
+	configFile := path.ReplaceTildePrefixWithHomeDir(config)
+
+	abs, err := filepath.Abs(configFile)
+	if err != nil {
+		log.Error(err)
+		return filepath.Clean(configFile)
+	}
+
+	return abs
+}
+
+func loadConfig(configFile string) *Config {
+	defer log.Trace(time.Now())
 
 	if len(configFile) == 0 {
-		env.Debug("no config file specified, using default")
-		return Default(env, false)
+		log.Debug("no config file specified, using default")
+		return Default(false)
 	}
 
 	var cfg Config
 	cfg.origin = configFile
 	cfg.Format = strings.TrimPrefix(filepath.Ext(configFile), ".")
-	cfg.env = env
 
 	data, err := stdOS.ReadFile(configFile)
 	if err != nil {
-		env.Error(err)
-		return Default(env, true)
+		log.Error(err)
+		return Default(true)
 	}
 
 	switch cfg.Format {
@@ -87,11 +140,9 @@ func loadConfig(env runtime.Environment) *Config {
 	}
 
 	if err != nil {
-		env.Error(err)
-		return Default(env, true)
+		log.Error(err)
+		return Default(true)
 	}
 
-	setDisableNotice(data, &cfg)
-
 	return &cfg
 }
