@@ -9,6 +9,7 @@ import (
 
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/color"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
@@ -105,7 +106,7 @@ func (segment *Segment) Execute(env runtime.Environment) {
 		return
 	}
 
-	segment.env.DebugF("segment: %s", segment.Name())
+	log.Debugf("segment: %s", segment.Name())
 
 	if segment.isToggled() {
 		return
@@ -121,7 +122,7 @@ func (segment *Segment) Execute(env runtime.Environment) {
 
 	if segment.writer.Enabled() {
 		segment.Enabled = true
-		env.TemplateCache().AddSegmentData(segment.Name(), segment.writer)
+		template.Cache.AddSegmentData(segment.Name(), segment.writer)
 	}
 }
 
@@ -134,13 +135,15 @@ func (segment *Segment) Render() {
 	segment.Enabled = len(strings.ReplaceAll(text, " ", "")) > 0
 
 	if !segment.Enabled {
-		segment.env.TemplateCache().RemoveSegmentData(segment.Name())
+		template.Cache.RemoveSegmentData(segment.Name())
 		return
 	}
 
 	segment.SetText(text)
 	segment.setCache()
-	segment.env.TemplateCache().AddSegmentData(segment.Name(), segment.writer)
+
+	// We do this to make `.Text` available for a cross-segment reference in an extra prompt.
+	template.Cache.AddSegmentData(segment.Name(), segment.writer)
 }
 
 func (segment *Segment) Text() string {
@@ -199,13 +202,14 @@ func (segment *Segment) hasCache() bool {
 func (segment *Segment) isToggled() bool {
 	toggles, OK := segment.env.Session().Get(cache.TOGGLECACHE)
 	if !OK || len(toggles) == 0 {
+		log.Debug("no toggles found")
 		return false
 	}
 
 	list := strings.Split(toggles, ",")
 	for _, toggle := range list {
 		if SegmentType(toggle) == segment.Type || toggle == segment.Alias {
-			segment.env.DebugF("segment toggled off: %s", segment.Name())
+			log.Debugf("segment toggled off: %s", segment.Name())
 			return true
 		}
 	}
@@ -220,16 +224,19 @@ func (segment *Segment) restoreCache() bool {
 
 	data, OK := segment.env.Session().Get(segment.cacheKey())
 	if !OK {
+		log.Debug("no cache found for segment: ", segment.Name())
 		return false
 	}
 
 	err := json.Unmarshal([]byte(data), &segment.writer)
 	if err != nil {
-		segment.env.Error(err)
+		log.Error(err)
 	}
 
 	segment.Enabled = true
-	segment.env.TemplateCache().AddSegmentData(segment.Name(), segment.writer)
+	template.Cache.AddSegmentData(segment.Name(), segment.writer)
+
+	log.Debug("restored segment from cache: ", segment.Name())
 
 	return true
 }
@@ -241,7 +248,7 @@ func (segment *Segment) setCache() {
 
 	data, err := json.Marshal(segment.writer)
 	if err != nil {
-		segment.env.Error(err)
+		log.Error(err)
 		return
 	}
 
