@@ -8,7 +8,7 @@ import (
 	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
 )
 
 type Python struct {
@@ -87,10 +87,10 @@ func (p *Python) loadContext() {
 			continue
 		}
 
-		name := runtime.Base(p.language.env, venv)
+		name := path.Base(venv)
 		if folderNameFallback && slices.Contains(defaultVenvNames, name) {
 			venv = strings.TrimSuffix(venv, name)
-			name = runtime.Base(p.language.env, venv)
+			name = path.Base(venv)
 		}
 
 		if p.canUseVenvName(name) {
@@ -121,23 +121,27 @@ func (p *Python) pyenvVersion() (string, error) {
 	// Use `pyenv root` instead of $PYENV_ROOT?
 	// Is our Python executable at $PYENV_ROOT/bin/python ?
 	// Should p.env expose command paths?
-	path := p.env.CommandPath("python")
-	if len(path) == 0 {
-		path = p.env.CommandPath("python3")
+	cmdPath := p.env.CommandPath("python")
+	if len(cmdPath) == 0 {
+		cmdPath = p.env.CommandPath("python3")
 	}
-	if len(path) == 0 {
+
+	if len(cmdPath) == 0 {
 		return "", errors.New("no python executable found")
 	}
+
 	pyEnvRoot := p.env.Getenv("PYENV_ROOT")
 	// TODO:  pyenv-win has this at $PYENV_ROOT/pyenv-win/shims
-	if path != filepath.Join(pyEnvRoot, "shims", "python") {
-		return "", fmt.Errorf("executable at %s is not a pyenv shim", path)
+	if cmdPath != filepath.Join(pyEnvRoot, "shims", "python") {
+		return "", fmt.Errorf("executable at %s is not a pyenv shim", cmdPath)
 	}
+
 	// pyenv version-name will return current version or virtualenv
 	cmdOutput, err := p.env.RunCommand("pyenv", "version-name")
 	if err != nil {
 		return "", err
 	}
+
 	versionString := strings.Split(cmdOutput, ":")[0]
 	if len(versionString) == 0 {
 		return "", errors.New("no pyenv version-name found")
@@ -148,34 +152,41 @@ func (p *Python) pyenvVersion() (string, error) {
 	if err != nil {
 		return "", err
 	}
+
 	// ../versions/(version)[/envs/(virtualenv)]
 	shortPath, err := filepath.Rel(filepath.Join(pyEnvRoot, "versions"), realPath)
 	if err != nil {
 		return "", err
 	}
+
 	// override virtualenv if pyenv set one
 	parts := strings.Split(shortPath, string(filepath.Separator))
 	if len(parts) > 2 && p.canUseVenvName(parts[2]) {
 		p.Venv = parts[2]
 	}
+
 	return parts[0], nil
 }
 
 func (p *Python) pyvenvCfgPrompt() string {
-	path := p.language.env.CommandPath("python")
-	if len(path) == 0 {
-		path = p.language.env.CommandPath("python3")
+	cmdPath := p.language.env.CommandPath("python")
+	if len(cmdPath) == 0 {
+		cmdPath = p.language.env.CommandPath("python3")
 	}
-	if len(path) == 0 {
+
+	if len(cmdPath) == 0 {
 		return ""
 	}
-	pyvenvDir := filepath.Dir(path)
+
+	pyvenvDir := filepath.Dir(cmdPath)
 	if !p.language.env.HasFilesInDir(pyvenvDir, "pyvenv.cfg") {
 		pyvenvDir = filepath.Dir(pyvenvDir)
 	}
+
 	if !p.language.env.HasFilesInDir(pyvenvDir, "pyvenv.cfg") {
 		return ""
 	}
+
 	pyvenvCfg := p.env.FileContent(filepath.Join(pyvenvDir, "pyvenv.cfg"))
 	for _, line := range strings.Split(pyvenvCfg, "\n") {
 		lineSplit := strings.SplitN(line, "=", 2)
@@ -188,5 +199,6 @@ func (p *Python) pyvenvCfgPrompt() string {
 			return value
 		}
 	}
+
 	return ""
 }
